let fireworks = [];

function setup() {
  createCanvas(windowWidth, windowHeight);

 
}

function startFireworks() {

  setInterval(() => {
    fireworks.push(new Firework());
  }, 1000);

  // Show the popup after 3 seconds
  setTimeout(() => {
    createPopup();
  }, 3000);
}

function draw() {
  background(0, 25);

  for (let i = fireworks.length - 1; i >= 0; i--) {
    fireworks[i].update();
    fireworks[i].show();
  
    if (fireworks[i].done()) {
      fireworks.splice(i, 1);
    }
  }
}

class Firework {
  constructor() {
    this.x = random(width);
    this.y = height;
    this.exploded = false; 
    this.explosionTimer = 0; 

    this.vx = random(-1, 1);
    this.vy = random(-20, -15); 
    this.explosionRadius = random(50, 150);
    this.explosionColor = color(random(255), random(255), random(255));

    this.missileTrail = [];
    this.explosionTrail = [];
  }

  update() {
    if (!this.exploded) {
      // Update missile position
      this.x += this.vx;
      this.y += this.vy;
      this.vy += 0.5;
      this.missileTrail.push(createVector(this.x, this.y));

      if (this.vy >= 0) {
        this.explode();
      }
    } else {
     
      for (let particle of this.explosionTrail) {
        particle.update();
      }
      this.explosionTimer++;
    }
  }

  show() {
    if (!this.exploded) {
     
      noFill();
      strokeWeight(3);
      stroke(255, 150); 
      beginShape();
      for (let pt of this.missileTrail) {
        vertex(pt.x, pt.y);
      }
      endShape();
    } else {
    
      for (let particle of this.explosionTrail) {
        particle.show();
      }
    }
  }

  explode() {
   
    for (let i = 0; i < 100; i++) {
      let angle = random(TWO_PI);
      let speed = random(2, 10);
      this.explosionTrail.push(new Particle(this.x, this.y, angle, speed, this.explosionRadius, this.explosionColor));
    }
    this.exploded = true;
  }

  done() {
  
    return this.exploded && this.explosionTimer > 60;
  }
}

class Particle {
  constructor(x, y, angle, speed, explosionRadius, explosionColor) {
    this.x = x;
    this.y = y;
    this.vx = cos(angle) * speed;
    this.vy = sin(angle) * speed;
    this.explosionRadius = explosionRadius;
    this.explosionColor = explosionColor;
    this.alpha = 255;
    this.size = random(2, 8);
  }

  update() {
    this.x += this.vx;
    this.y += this.vy;
    this.alpha -= 5;
  }

  show() {
    noStroke();
    fill(this.explosionColor.levels[0], this.explosionColor.levels[1], this.explosionColor.levels[2], this.alpha);
    ellipse(this.x, this.y, this.size, this.size); 
  }
}




const nums = document.querySelectorAll('.nums span')
const counter = document.querySelector('.counter')
const finalMessage = document.querySelector('.final')
const replay = document.querySelector('#replay')

runAnimation()

function resetDOM() {
  counter.classList.remove('hide')
  finalMessage.classList.remove('show')

  nums.forEach((num) => {
    num.classList.value = ''
  })

  nums[0].classList.add('in')
}

function runAnimation() {
  nums.forEach((num, idx) => {
    const nextToLast = nums.length - 1

    num.addEventListener('animationend', (e) => {
      if (e.animationName === 'goIn' && idx !== nextToLast) {
        num.classList.remove('in')
        num.classList.add('out')
      } else if (e.animationName === 'goOut' && num.nextElementSibling) {
        num.nextElementSibling.classList.add('in')
       
      } else {
        counter.classList.add('hide')
        finalMessage.classList.add('show')
        startFireworks();
      }
    })
  })
}

replay.addEventListener('click', () => {
  setup()
  resetDOM()
  runAnimation()
})
